pub struct PromptAnswer {
pub result: bool,
pub time: f32,
pub metadata: Option<AnswerMetadata>,
}Fields
result: boolThe user’s answer to whether or not they approve this prompt.
time: f32The unix timestamp when the user answered the prompt.
metadata: Option<AnswerMetadata>Implementations
Sourceimpl PromptAnswer
impl PromptAnswer
pub fn new(result: bool, time: f32) -> PromptAnswer